@@ -1,37 +1,36 @@
 """
 Tools for interacting with bank accounts in the database.
 """
-from werkzeug.exceptions import abort
 import sqlalchemy.sql.functions as sql_func
+from werkzeug.exceptions import abort
 
 from ..common.forms.utils import execute_on_form_validation
 from ..database.handler import DatabaseViewHandler
 from ..database.models import (
-    Bank, BankAccountType, BankAccountTypeView, BankAccount, BankAccountView
+    Bank,
+    BankAccount,
+    BankAccountType,
+    BankAccountTypeView,
+    BankAccountView,
 )
 
 
-class BankAccountTypeHandler(DatabaseViewHandler):
+class BankAccountTypeHandler(
+    DatabaseViewHandler, model=BankAccountType, model_view=BankAccountTypeView
+):
     """
     A database handler for managing bank account types.
 
-    Parameters
-    ----------
-    user_id : int
-        The ID of the user who is the subject of database access. If not
-        given, the handler defaults to using the logged-in user.
-
     Attributes
     ----------
-    table : str
-        The name of the database table that this handler manages.
-    db : sqlite3.Connection
-        A connection to the database for interfacing.
     user_id : int
         The ID of the user who is the subject of database access.
+    model : type
+        The type of database model that the handler is primarily
+        designed to manage.
+    table : str
+        The name of the database table that this handler manages.
     """
-    _model = BankAccountType
-    _model_view = BankAccountTypeView
 
     @classmethod
     @DatabaseViewHandler.view_query
@@ -119,32 +118,29 @@ class BankAccountTypeHandler(DatabaseViewHandler):
         account_type = super()._confirm_manipulation_authorization(entry_id)
         # Limit manipulation to only the user (excluding common entries)
         if account_type.user_id != cls.user_id:
-            abort_msg = ("The current user is not authorized to manipulate "
-                         "this account type entry.")
+            abort_msg = (
+                "The current user is not authorized to manipulate "
+                "this account type entry."
+            )
             abort(404, abort_msg)
 
 
-class BankAccountHandler(DatabaseViewHandler):
+class BankAccountHandler(
+    DatabaseViewHandler, model=BankAccount, model_view=BankAccountView
+):
     """
     A database handler for managing bank accounts.
 
-    Parameters
-    ----------
-    user_id : int
-        The ID of the user who is the subject of database access. If not
-        given, the handler defaults to using the logged-in user.
-
     Attributes
     ----------
-    table : str
-        The name of the database table that this handler manages.
-    db : sqlite3.Connection
-        A connection to the database for interfacing.
     user_id : int
         The ID of the user who is the subject of database access.
+    model : type
+        The type of database model that the handler is primarily
+        designed to manage.
+    table : str
+        The name of the database table that this handler manages.
     """
-    _model = BankAccount
-    _model_view = BankAccountView
 
     @classmethod
     @DatabaseViewHandler.view_query
@@ -185,15 +181,17 @@ class BankAccountHandler(DatabaseViewHandler):
         query = query.where(Bank.id == bank_id)
         balance = cls._db.session.execute(query).scalar()
         if balance is None:
-            abort_msg = ("No balance was found for the given combination of "
-                         "user and account.")
+            abort_msg = (
+                "No balance was found for the given combination of user and account."
+            )
             abort(404, abort_msg)
         return balance
 
     @classmethod
     @DatabaseViewHandler.view_query
-    def find_account(cls, bank_name=None, account_type_name=None,
-                     last_four_digits=None):
+    def find_account(
+        cls, bank_name=None, account_type_name=None, last_four_digits=None
+    ):
         """
         Find a bank account using uniquely identifying characteristics.
 
@@ -226,8 +224,7 @@ class BankAccountHandler(DatabaseViewHandler):
         """
         criteria = [
             cls._filter_value(Bank.bank_name, bank_name),
-            cls._filter_value(BankAccountTypeView.type_name,
-                              account_type_name),
+            cls._filter_value(BankAccountTypeView.type_name, account_type_name),
             cls._filter_value(cls.model.last_four_digits, last_four_digits),
         ]
         account = super().find_entry(*criteria)
@@ -277,10 +274,10 @@ def save_account(form, account_id=None):
     """
     account_data = form.account_data
     if account_id:
-        raise NotImplementedError("The ability to update the account is not "
-                                  "yet supported.")
+        raise NotImplementedError(
+            "The ability to update the account is not yet supported."
+        )
     else:
         # Insert the new account into the database
         account = BankAccountHandler.add_entry(**account_data)
     return account
-
