@@ -5,28 +5,21 @@ from ..database.handler import DatabaseHandler
 from ..database.models import CreditAccount
 
 
-class CreditAccountHandler(DatabaseHandler):
+class CreditAccountHandler(DatabaseHandler, model=CreditAccount):
     """
     A database handler for managing credit accounts.
 
-    Parameters
-    ----------
-    user_id : int
-        The ID of the user who is the subject of database access. If not
-        given, the handler defaults to using the logged-in user.
-
     Attributes
     ----------
-    table : str
-        The name of the database table that this handler manages.
-    db : sqlite3.Connection
-        A connection to the database for interfacing.
     user_id : int
         The ID of the user who is the subject of database access.
+    model : type
+        The type of database model that the handler is primarily
+        designed to manage.
+    table : str
+        The name of the database table that this handler manages.
     """
 
-    model = CreditAccount
-
     @classmethod
     def get_accounts(cls, bank_ids=None):
         """
