@@ -6,28 +6,21 @@ from ..database.handler import DatabaseHandler
 from ..database.models import Bank, CreditAccount, CreditCard
 
 
-class CreditCardHandler(DatabaseHandler):
+class CreditCardHandler(DatabaseHandler, model=CreditCard):
     """
     A database handler for managing credit cards.
 
-    Parameters
-    ----------
-    user_id : int
-        The ID of the user who is the subject of database access. If not
-        given, the handler defaults to using the logged-in user.
-
     Attributes
     ----------
-    table : str
-        The name of the database table that this handler manages.
-    db : sqlite3.Connection
-        A connection to the database for interfacing.
     user_id : int
         The ID of the user who is the subject of database access.
+    model : type
+        The type of database model that the handler is primarily
+        designed to manage.
+    table : str
+        The name of the database table that this handler manages.
     """
 
-    model = CreditCard
-
     @classmethod
     def get_cards(
         cls, bank_ids=None, account_ids=None, last_four_digits=None, active=None
