@@ -26,7 +26,7 @@ from .actions import (
 )
 from .blueprint import bp
 from .cards import CreditCardHandler, save_card
-from .forms import *
+from .forms import CardStatementTransferForm, CreditCardForm, CreditTransactionForm
 from .statements import CreditStatementHandler
 from .transactions import CreditTagHandler, CreditTransactionHandler, save_transaction
 
@@ -384,7 +384,9 @@ def add_subtransaction_fields():
         subtransaction_count,
     )
     return render_template(
-        "credit/transaction_form/subtransaction_form.html", subform=new_subform
+        "credit/transaction_form/subtransaction_form.html",
+        subform=new_subform,
+        field_list_optional_member=True,
     )
 
 
@@ -451,8 +453,8 @@ def suggest_transaction_autocomplete():
     if field != "note":
         suggestions = CreditTransactionForm.autocomplete(field)
     else:
-        vendor = post_args["vendor"]
-        suggestions = CreditTransactionForm.autocomplete("note", vendor=vendor)
+        merchant = post_args["merchant"]
+        suggestions = CreditTransactionForm.autocomplete("note", merchant=merchant)
     return jsonify(suggestions)
 
 
