@@ -11,29 +11,23 @@ from ..database.models import (
 )
 
 
-class CreditStatementHandler(DatabaseViewHandler):
+class CreditStatementHandler(
+    DatabaseViewHandler, model=CreditStatement, model_view=CreditStatementView
+):
     """
     A database handler for managing credit card statements.
 
-    Parameters
-    ----------
-    user_id : int
-        The ID of the user who is the subject of database access. If not
-        given, the handler defaults to using the logged-in user.
-
     Attributes
     ----------
-    table : str
-        The name of the database table that this handler manages.
-    db : sqlite3.Connection
-        A connection to the database for interfacing.
     user_id : int
         The ID of the user who is the subject of database access.
+    model : type
+        The type of database model that the handler is primarily
+        designed to manage.
+    table : str
+        The name of the database table that this handler manages.
     """
 
-    _model = CreditStatement
-    _model_view = CreditStatementView
-
     @classmethod
     @DatabaseViewHandler.view_query
     def get_statements(
