@@ -2,39 +2,43 @@
 Tools for interacting with the credit transactions in the database.
 """
 from ..common.forms.utils import execute_on_form_validation
+from ..common.transactions import TransactionHandler
 from ..database.handler import DatabaseHandler, DatabaseViewHandler
-from ..database.models  import (
-    Bank, CreditAccount, CreditCard, CreditStatementView, CreditTransaction,
-    CreditTransactionView, CreditSubtransaction, CreditTag, tag_link_table
+from ..database.models import (
+    Bank,
+    CreditAccount,
+    CreditCard,
+    CreditStatementView,
+    CreditSubtransaction,
+    CreditTag,
+    CreditTransaction,
+    CreditTransactionView,
+    tag_link_table,
 )
 
 
-class CreditTransactionHandler(DatabaseViewHandler):
+class CreditTransactionHandler(
+    TransactionHandler, model=CreditTransaction, model_view=CreditTransactionView
+):
     """
     A database handler for accessing credit transactions.
 
-    Parameters
-    ----------
-    user_id : int
-        The ID of the user who is the subject of database access. If not
-        given, the handler defaults to using the logged-in user.
-
     Attributes
     ----------
-    table : str
-        The name of the database table that this handler manages.
-    db : sqlite3.Connection
-        A connection to the database for interfacing.
     user_id : int
         The ID of the user who is the subject of database access.
+    model : type
+        The type of database model that the handler is primarily
+        designed to manage.
+    table : str
+        The name of the database table that this handler manages.
     """
-    _model = CreditTransaction
-    _model_view = CreditTransactionView
 
     @classmethod
     @DatabaseViewHandler.view_query
-    def get_transactions(cls, statement_ids=None, card_ids=None, active=None,
-                    sort_order='DESC'):
+    def get_transactions(
+        cls, statement_ids=None, card_ids=None, active=None, sort_order="DESC"
+    ):
         """
         Get credit card transactions from the database.
 
@@ -75,17 +79,6 @@ class CreditTransactionHandler(DatabaseViewHandler):
         transactions = super().get_entries(*criteria, sort_order=sort_order)
         return transactions
 
-    @classmethod
-    def _customize_entries_query(cls, query, filters, sort_order):
-        query = super()._customize_entries_query(query, filters, sort_order)
-        # Group transactions and order by transaction date
-        query = query.group_by(cls.model.id)
-        query = cls._sort_query(
-            query,
-            (cls.model.transaction_date, sort_order),
-        )
-        return query
-
     @classmethod
     def add_entry(cls, **field_values):
         """
@@ -108,72 +101,43 @@ class CreditTransactionHandler(DatabaseViewHandler):
         transaction : database.models.CreditTransaction
             The saved transaction.
         """
-        # Extend the default method to account for subtransactions
-        subtransactions_data = field_values.pop('subtransactions')
-        transaction = super().add_entry(**field_values)
-        cls._add_subtransactions(transaction, subtransactions_data)
-        # Refresh the transaction with the subtransaction information
-        cls._db.session.refresh(transaction)
-        return transaction
+        return super().add_entry(**field_values)
 
-    @classmethod
-    def update_entry(cls, entry_id, **field_values):
-        """Update a transaction in the database."""
-        # Extend the default method to account for subtransactions
-        subtransactions_data = field_values.pop('subtransactions', None)
-        transaction = super().update_entry(entry_id, **field_values)
-        if subtransactions_data:
-            # Replace all subtransactions when updating any subtransaction
-            for subtransaction in transaction.subtransactions:
-                cls._db.session.delete(subtransaction)
-            cls._add_subtransactions(transaction, subtransactions_data)
-        # Refresh the transaction with the subtransaction information
-        cls._db.session.refresh(transaction)
-        return transaction
-
-    @classmethod
-    def _add_subtransactions(cls, transaction, subtransactions_data):
-        """Add subtransactions to the database for the data given."""
-        for subtransaction_data in subtransactions_data:
-            tag_names = subtransaction_data.pop("tags")
-            # NOTE I don't believe that this adds new tags to the database
-            tags = CreditTagHandler.get_tags(tag_names, ancestors=True)
-            subtransaction = CreditSubtransaction(
-                transaction_id=transaction.id,
-                **subtransaction_data,
-                tags=tags,
-            )
-            cls._db.session.add(subtransaction)
-        # Flush to the database after all subtransactions have been added
-        cls._db.session.flush()
+    @staticmethod
+    def _prepare_subtransaction(transaction, subtransaction_data):
+        """Prepare a subtransaction for the given transaction."""
+        # NOTE I don't believe that this adds new tags to the database
+        tag_names = subtransaction_data.pop("tags")
+        return CreditSubtransaction(
+            transaction_id=transaction.id,
+            **subtransaction_data,
+            tags=CreditTagHandler.get_tags(tag_names, ancestors=True),
+        )
 
 
-class CreditTagHandler(DatabaseHandler):
+class CreditTagHandler(DatabaseHandler, model=CreditTag):
     """
     A database handler for managing credit transaction tags.
 
-    Parameters
-    ----------
-    user_id : int
-        The ID of the user who is the subject of database access. If not
-        given, the handler defaults to using the logged-in user.
-
     Attributes
     ----------
-    table : str
-        The name of the database table that this handler manages.
-    db : sqlite3.Connection
-        A connection to the database for interfacing.
-    cursor : sqlite.Cursor
-        A cursor for executing database interactions.
     user_id : int
         The ID of the user who is the subject of database access.
+    model : type
+        The type of database model that the handler is primarily
+        designed to manage.
+    table : str
+        The name of the database table that this handler manages.
     """
-    model = CreditTag
 
     @classmethod
-    def get_tags(cls, tag_names=None, transaction_ids=None,
-                 subtransaction_ids=None, ancestors=None):
+    def get_tags(
+        cls,
+        tag_names=None,
+        transaction_ids=None,
+        subtransaction_ids=None,
+        ancestors=None,
+    ):
         """
         Get credit card transaction tags from the database.
 
@@ -229,13 +193,15 @@ class CreditTagHandler(DatabaseHandler):
     @classmethod
     def _filter_entries(cls, query, filters):
         # Add a join to enable filtering by transaction ID or subtransaction ID
-        query = query.join(tag_link_table) \
-                     .join(CreditSubtransaction) \
-                     .join(CreditTransactionView) \
-                     .join(CreditStatementView) \
-                     .join(CreditCard) \
-                     .join(CreditAccount) \
-                     .join(Bank)
+        query = (
+            query.join(tag_link_table)
+            .join(CreditSubtransaction)
+            .join(CreditTransactionView)
+            .join(CreditStatementView)
+            .join(CreditCard)
+            .join(CreditAccount)
+            .join(Bank)
+        )
         # Only get distinct tag entries
         query = query.distinct()
         return super()._filter_entries(query, filters)
@@ -401,4 +367,3 @@ def save_transaction(form, transaction_id=None):
         # Insert the new transaction into the database
         transaction = CreditTransactionHandler.add_entry(**transaction_data)
     return transaction
-
